@@ -10,11 +10,12 @@ our @EXPORT_OK = qw/
     last_value_from first_value_from
 /;
 
-our $VERSION = "v6.6.0";
+our $VERSION = "v6.6.1";
 
 sub _promise_class {
     my $fn = (caller(1))[3];
-    my $rx_class = $fn =~ s/\:\:[^\:]+\z//r;
+    my $rx_class = $fn;
+    $rx_class =~ s/\:\:[^\:]+\z//;
     no strict 'refs';
     my $promise_class = ${ "${rx_class}::promise_class" };
     return $promise_class;
